<?php
namespace Pixi_Adv_Portfolio;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor Widget 2.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class pixi_adv_portfolio_filter extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 */
	public function get_name() {
		return 'pixi-adv-gallery-filter';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve  widget title.
	 */
	public function get_title() {
		return esc_html__( 'Pixi Portfolio Filter', 'pixi-adv-portfolio' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve  widget icon.
	 *
	 */
	public function get_icon() {
		return 'eicon-gallery-masonry';
	}


	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the  widget belongs to.
	 *
	 */
	public function get_categories() {
		return [ 'pixi-adv-category' ];
	}


	/**
	 * Get widget style depends
	 *
	 * Retrieve the list of categories the  widget belongs to.
	 *
	 */


	public function get_style_depends() {
		return [
			'widget-common-style',
			'hover-style-default',
			'hover-style-1',
			'hover-style-2',
			'hover-style-3',
			'hover-style-4',
			'bootstrap',
			'lineicons',
		];
	}
	
	/**
	 * Get widget Script depends
	 *
	 * Retrieve the list of categories the  widget belongs to.
	 *
	 */

	public function get_script_depends() {
		return [
			'isotope',
			'image-loaded',
			'pixi-filter-gallery',
			'popup-script',
		];
	}
	
	

	/**
	 * Register  widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.

	 */
	protected function register_controls() {

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'Settings', 'pixi-adv-portfolio' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'layout_style',
			[
				'label' => esc_html__( 'Layout Style', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'layout-default',
				'options' => [
					'layout-default' => esc_html__('Default', 'pixi-adv-portfolio' ),
					'layout-1' => esc_html__(' Layout 1', 'pixi-adv-portfolio' ),
					'layout-2' => esc_html__( 'Layout 2', 'pixi-adv-portfolio' ),
					'layout-3' => esc_html__( 'Layout 3', 'pixi-adv-portfolio' ),
					'layout-4' => esc_html__( 'Layout 4', 'pixi-adv-portfolio' ),
				],
			]
		);

		$this->add_control(
			'img_style',
			[
				'label' => esc_html__( 'Img hover Style', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'layout-2',
				'options' => [
					'layout-1' => esc_html__('Default', 'pixi-adv-portfolio' ),
					'layout-2' => esc_html__('Grayscale', 'pixi-adv-portfolio' ),
				],
				'condition' => [
					'layout_style' => ['layout-2','layout-4'],
				],
			]
		);

		$this->add_control(
			'column_option',
			[
				'label' => esc_html__( 'Column', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '4',
				'options' => [
					'12'  => esc_html__( '1', 'pixi-adv-portfolio' ),
					'6' => esc_html__( '2', 'pixi-adv-portfolio' ),
					'4' => esc_html__( '3', 'pixi-adv-portfolio' ),
					'3' => esc_html__( '4', 'pixi-adv-portfolio' ),
				],
			]
		);

		$this->add_control(
			'column_gap',
			[
				'label' => esc_html__( 'Columns Gap', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'default',
				'options' => [
					'default'  => esc_html__( 'Default', 'pixi-adv-portfolio' ),
					'g-0' => esc_html__( 'No Gap', 'pixi-adv-portfolio' ),
					'g-1' => esc_html__( 'Narrrow', 'pixi-adv-portfolio' ),
					'g-2' => esc_html__( 'Extended', 'pixi-adv-portfolio' ),
					'g-3' => esc_html__( 'Wide', 'pixi-adv-portfolio' ),
					'g-4' => esc_html__( 'Wider', 'pixi-adv-portfolio' ),
					'g-custom' => esc_html__( 'Custom', 'pixi-adv-portfolio' ),
				],
			]
		);

		$this->add_responsive_control(
			'custom_column_gap',
			[
				'label' => esc_html__( 'Custom Column Gap', 'eduhash-toolkit' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'default' => [
					'unit' => 'px',
					'size' => 0,
				],
				'condition' => [
					'column_gap' => 'g-custom',
				],
				'selectors' => [
					'{{WRAPPER}} .pixi-gallery-wrapper .gallery-inner ' => 'margin-bottom: -{{SIZE}}{{UNIT}}; margin-right: -{{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .pixi-gallery-wrapper .pixi-inner-item' => 'padding-right: {{SIZE}}{{UNIT}}; padding-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'content_item_spacing',
			[
				'label' => esc_html__( 'Spacing', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px'],
				'default' => [
					'unit' => 'px',
					'size' => 20,
				],
				'selectors' => [
					'{{WRAPPER}} .pixi-portfolio .pixi-inner-item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'enable_filter',
			[
				'label' => __( 'Show Filter', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'pixi-adv-portfolio' ),
				'label_off' => __( 'Hide', 'pixi-adv-portfolio' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);


		$this->end_controls_section();

		// filter option

		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Filter Controls', 'pixi-adv-portfolio' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'condition' => array(
					'enable_filter' => 'yes',
				)
			]
		);


		$this->add_control(
			'all_title',
			[
				'label' => esc_html__( 'Gallery All Label', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'All', 'pixi-adv-portfolio' ),
				'placeholder' => esc_html__( 'Type your title here', 'pixi-adv-portfolio' ),
				'condition' => array(
					'enable_filter' => 'yes',
				)
			]
		);


		$filter_repeater = new \Elementor\Repeater();

		$filter_repeater->add_control(
			'filter_name',
			[
				'label' => esc_html__( 'Filter Label', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Gallery Item', 'pixi-adv-portfolio' ),
				'placeholder' => esc_html__( 'Type your title here', 'pixi-adv-portfolio' ),
			]
		);


		$this->add_control(
			'filter_lists',
			[
				'label' => __( 'Filter Item', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $filter_repeater->get_controls(),
				'title_field' => '{{{ filter_name }}}',
				'condition' => array(
					'enable_filter' => 'yes',
				),
				'default' => [
					[
						'filter_name' => esc_html__( 'Gallery Item', 'pixi-adv-portfolio' ),
					],
					[
						'filter_name' => esc_html__( 'Gallery Item 2', 'pixi-adv-portfolio' ),
					],
					[
						'filter_name' => esc_html__( 'Gallery Item 3', 'pixi-adv-portfolio' ),
					],
					[
						'filter_name' => esc_html__( 'Gallery Item 4', 'pixi-adv-portfolio' ),
					],
				],
			]
		);

		// Repeater End
		$this->end_controls_section();

		// filter option

		$this->start_controls_section(
			'item_content_section',
			[
				'label' => esc_html__( 'Gallery Content', 'pixi-adv-portfolio' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		

		// Repeater Start

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'control_name',
			[
				'label' => esc_html__( 'Control Name', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => esc_html__( 'Gallery Item', 'pixi-adv-portfolio' ),
				'placeholder' => esc_html__( 'Use the gallery control name from Control Settings. Separate multiple 
				items with comma (e.g. Gallery Item, Gallery Item 2)', 'pixi-adv-portfolio' ),
				'label_block' => true,
				'rows' => 3,
			]
		);

		$repeater->add_control(
			'widget_image',
			[
				'label' => esc_html__( 'Choose Image', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'widget_title',
			[
				'label' => esc_html__( 'Title', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'App Development.', 'pixi-adv-portfolio' ),
				'placeholder' => esc_html__( 'Type your title here', 'pixi-adv-portfolio' ),
				'label_block' => true
			]
		);
		$repeater->add_control(
			'widget_cat',
			[
				'label' => esc_html__( 'Category', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'App Development.', 'pixi-adv-portfolio' ),
				'placeholder' => esc_html__( 'Type your title here', 'pixi-adv-portfolio' ),
				'label_block' => true
			]
		);

		$repeater->add_control(
			'widget_desc',
			[
				'label' => esc_html__( 'Description', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'rows' => 10,
				'default' => esc_html__( 'Description here', 'pixi-adv-portfolio' ),
				'placeholder' => esc_html__( 'Type your description here', 'pixi-adv-portfolio' ),
			]
		);


		$repeater->add_control(
			'link_option',
			[
				'label' => esc_html__( 'Link', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'media',
				'options' => [
					'media'  => esc_html__( 'Media File', 'pixi-adv-portfolio' ),
					'custom' => esc_html__( 'Custom Link', 'pixi-adv-portfolio' ),
				],
			]
		);

		$repeater->add_control(
			'widget_link',
			[
				'label' => esc_html__( 'Link', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'pixi-adv-portfolio' ),
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
				'condition' => array(
					'link_option' => ['custom'],
				)
			]
		);
		

		$this->add_control(
			'gallery_lists',
			[
				'label' => __( 'Gallery Images', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'widget_image' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
					],
					[
						'widget_image' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
					],
					[
						'widget_image' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
					],
					[
						'widget_image' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
					],
					[
						'widget_image' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
					],
					[
						'widget_image' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
					],

				],
			]
		);

		$this->end_controls_section();


		//  Filter Control STyle controls

		$this->start_controls_section(
			'filter_style_section',
			[
				'label' => esc_html__( 'Filter Style', 'pixi-adv-portfolio' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'filter_align',
			[
				'label' => esc_html__( 'Alignment', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'pixi-adv-portfolio' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'pixi-adv-portfolio' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'pixi-adv-portfolio' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'toggle' => true,
				'selectors' => [
					'{{WRAPPER}} .pixi-portfolio .pixi-filter ' => 'text-align: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'filter_typography',
				'selector' => '{{WRAPPER}} .pixi-portfolio .pixi-filter button',
			]
		);

		$this->add_control(
			'filter_radius',
			[
				'label' => esc_html__( 'Border radius', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .pixi-portfolio .pixi-filter button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'filter_border',
				'label' => __( 'Border', 'pixi-adv-portfolio' ),
				'selector' => '{{WRAPPER}}  .pixi-portfolio .pixi-filter button',
			]
		);
		$this->add_control(
			'filter_active_border_color',
			[
				'label' => esc_html__( 'Active Border Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-portfolio .pixi-filter button.active' => 'color: {{VALUE}}',
				],
			]
		);
		
		$this->add_control(
			'filter_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-portfolio .pixi-filter button' => 'background: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'filter_active_bg_color',
			[
				'label' => esc_html__( 'Active Background', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-portfolio .pixi-filter button.active' => 'background: {{VALUE}}',
				],
			]
		);


		$this->add_control(
			'filter_text_color',
			[
				'label' => esc_html__( 'Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-portfolio .pixi-filter button' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'filter_active_text_color',
			[
				'label' => esc_html__( 'Active text Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-portfolio .pixi-filter button.active' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'filter_padding',
			[
				'label' => esc_html__( 'Padding', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .pixi-portfolio .pixi-filter button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->add_responsive_control(
			'filter_spacing',
			[
				'label' => esc_html__( 'Spacing', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px'],
				
				'default' => [
					'unit' => 'px',
					'size' => 50,
				],

				'selectors' => [
					'{{WRAPPER}} .pixi-portfolio .pixi-filter' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'filter_item_spacing',
			[
				'label' => esc_html__( 'Item Spacing', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .pixi-portfolio .pixi-filter button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->end_controls_section();

		//  STyle controls

		$this->start_controls_section(
			'img_style_section',
			[
				'label' => esc_html__( 'Image', 'pixi-adv-portfolio' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_control(
			'image_radius',
			[
				'label' => esc_html__( 'Border radius', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Title Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item h3' => 'color: {{VALUE}}',
					'{{WRAPPER}} .pixi-inner-item h3 a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'title_hover_color',
			[
				'label' => esc_html__( 'Title Hover Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item:hover h3' => 'color: {{VALUE}}',
					'{{WRAPPER}} .pixi-inner-item:hover h3 a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .pixi-inner-item h3',
				'label' => esc_html__( 'Title Typography', 'pixi-adv-portfolio' ),
			]
		);

		$this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item p' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'text_hover_color',
			[
				'label' => esc_html__( 'Text Hover Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item:hover p' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'selector' => '{{WRAPPER}} .pixi-inner-item p',
				'label' => esc_html__( 'Text Typography', 'pixi-adv-portfolio' ),
			]
		);

		$this->add_control(
			'cat_color',
			[
				'label' => esc_html__( 'Category Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item .category' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout_style' => ['layout-2'],
				],
			]
		);
		$this->add_control(
			'cat_hover_color',
			[
				'label' => esc_html__( 'Category Hover Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item:hover .category' => 'color: {{VALUE}}',
				],
				'condition' => [
					'layout_style' => ['layout-2'],
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'cat_typography',
				'selector' => '{{WRAPPER}} .pixi-inner-item .category',
				'condition' => [
					'layout_style' => ['layout-2'],
				],
			]
		);

		$this->add_control(
			'btn_color',
			[
				'label' => esc_html__( 'Button Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item .btn-icon' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'btn_hover_color',
			[
				'label' => esc_html__( 'Button Hover Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item:hover .btn-icon' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();


		// content Style

		$this->start_controls_section(
			'content_style_section',
			[
				'label' => esc_html__( 'Content Item', 'pixi-adv-portfolio' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'item_border',
				'label' => __( 'Border', 'pixi-adv-portfolio' ),
				'selector' => '{{WRAPPER}}  .pixi-inner-item .inner-content',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'item_border2',
				'label' => __( 'Border', 'pixi-adv-portfolio' ),
				'selector' => '{{WRAPPER}}  .pixi-inner-item:hover .inner-content',
				'condition' => [
					'layout_style' => ['layout-default'],
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'item_box_shadow2',
				'label' => __( 'Box Shadow', 'pixi-adv-portfolio' ),
				'selector' => '{{WRAPPER}} .pixi-inner-item:hover .inner-content',
				'condition' => [
					'layout_style' => ['layout-default'],
				],
			]
		);

		$this->add_control(
			'content_bg_color2',
			[
				'label' => esc_html__( 'Background Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item:hover .inner-content' => 'background: {{VALUE}}',
				],
				'condition' => [
					'layout_style' => ['layout-default'],
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'item_box_shadow',
				'label' => __( 'Box Shadow', 'pixi-adv-portfolio' ),
				'selector' => '{{WRAPPER}} .pixi-inner-item .inner-content',
			]
		);

		$this->add_control(
			'content_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item .inner-content' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'content_hover_bg_color',
			[
				'label' => esc_html__( 'Hover Background', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item .inner-content::before' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'content_padding',
			[
				'label' => esc_html__( 'Padding', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item .inner-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'content_radius',
			[
				'label' => esc_html__( 'Border radius', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item .inner-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Render  widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();

		$layout= $settings['layout_style'];

		$img_style = $settings['img_style'];
		
		if('layout-2' == $img_style){
			$img_class = "gray";
		}
		else{
			$img_class ='';
		}

		?>

		<!-- Start Portfolio here -->
		<div class="pixi-portfolio">
			<div class="pixi-filter">
				<?php 
				if ( 'yes' === $settings['enable_filter'] ) { 
					?>
					<button class="active" data-filter="*"><?php echo esc_html($settings['all_title'],'pixi-adv-portfolio');?></button>
					
				<?php } ?>
				
				<?php foreach($settings['filter_lists'] as $filter_item){ 
					$remove_space_filter = str_replace(' ', '', $filter_item['filter_name']);

					$final_filter_name = str_replace(',', ' ', $remove_space_filter);

					?>
					<button data-filter=".<?php echo esc_attr($final_filter_name,'pixi-adv-portfolio')?>"><?php echo esc_html($filter_item['filter_name'],'pixi-adv-portfolio');?></button>
				<?php } ?>
			</div>                       


				<div class="row pixi-grid pixi-gallery-wrapper <?php echo esc_attr($settings['column_gap']); ?>">
				<?php foreach($settings['gallery_lists'] as $gallery_item){ 
						
						$control_name_lists = explode(", ", $gallery_item['control_name']);

						$control_single_name = implode(" " ,$control_name_lists);

						$new_str_name = str_replace(' ', '', $gallery_item['control_name']);

						$new_str_name = str_replace(',', ' ', $new_str_name);

					?>

					<div class="col-xl-<?php echo esc_attr($settings['column_option']); ?> col-lg-<?php echo esc_attr($settings['column_option']); ?>  col-md-6 grid-item <?php echo esc_attr($new_str_name,'pixi-adv-portfolio'); ?> elementor-repeater-item-<?php echo esc_attr( $gallery_item['_id'] )?>">
					<?php
						
						switch($layout){
							case 'layout-default';
								include( __DIR__ . '/layout/layout-default.php' );
							break;

							case 'layout-1';
								include( __DIR__ . '/layout/layout-1.php' );
							break;

							case 'layout-2';
								include( __DIR__ . '/layout/layout-2.php' );
							break;

							case 'layout-3';
								include( __DIR__ . '/layout/layout-3.php' );
							break;

							case 'layout-4';
								include( __DIR__ . '/layout/layout-4.php' );
							break;

							default:
								include( __DIR__ . '/layout/layout-default.php' );

						}

						?>

					</div> 
					<?php } ?>
			</div>
		</div>
		<!-- End Portfolio here -->    
		
			
	


		<?php 

		

	}

}
