<?php
namespace Pixi_Adv_Portfolio;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor Widget 2.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class pixi_adv_portfolio_1 extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve widget name.
	 *
	 */
	public function get_name() {
		return 'pixi-adv-gallery-1';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve  widget title.
	 */
	public function get_title() {
		return esc_html__( 'Pixi Portfolio 1', 'pixi-adv-portfolio' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve  widget icon.
	 *
	 */
	public function get_icon() {
		return 'eicon-gallery-grid';
	}


	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the  widget belongs to.
	 *
	 */
	public function get_categories() {
		return [ 'pixi-adv-category' ];
	}


	/**
	 * Get widget style depends
	 *
	 * Retrieve the list of categories the  widget belongs to.
	 *
	 */


	public function get_style_depends() {
		return [
			'widget-common-style',
			'hover-style-default',
			'hover-style-1',
			'bootstrap',
			'lineicons',
		];
	}
	
	/**
	 * Get widget Script depends
	 *
	 * Retrieve the list of categories the  widget belongs to.
	 *
	 */

	public function get_script_depends() {
		return [
			'isotope',
			'image-loaded',
			'pixi-filter-gallery',
			'popup-script',
		];
	}
	
	

	/**
	 * Register  widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.

	 */
	protected function register_controls() {

		$this->start_controls_section(
			'item_content_section',
			[
				'label' => esc_html__( 'Gallery Content', 'pixi-adv-portfolio' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		

		$this->add_control(
			'widget_image',
			[
				'label' => esc_html__( 'Choose Image', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'widget_title',
			[
				'label' => esc_html__( 'Title', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'App Development.', 'pixi-adv-portfolio' ),
				'placeholder' => esc_html__( 'Type your title here', 'pixi-adv-portfolio' ),
				'label_block' => true
			]
		);
		$this->add_control(
			'widget_cat',
			[
				'label' => esc_html__( 'Category', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'App Development.', 'pixi-adv-portfolio' ),
				'placeholder' => esc_html__( 'Type your title here', 'pixi-adv-portfolio' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'widget_desc',
			[
				'label' => esc_html__( 'Description', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'rows' => 10,
				'default' => esc_html__( 'Description here', 'pixi-adv-portfolio' ),
				'placeholder' => esc_html__( 'Type your description here', 'pixi-adv-portfolio' ),
			]
		);


		$this->add_control(
			'link_option',
			[
				'label' => esc_html__( 'Link', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'media',
				'options' => [
					'media'  => esc_html__( 'Media File', 'pixi-adv-portfolio' ),
					'custom' => esc_html__( 'Custom Link', 'pixi-adv-portfolio' ),
				],
			]
		);

		$this->add_control(
			'widget_link',
			[
				'label' => esc_html__( 'Link', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'pixi-adv-portfolio' ),
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
				'condition' => array(
					'link_option' => ['custom'],
				)
			]
		);
		

		$this->end_controls_section();


		
		//  STyle controls

		$this->start_controls_section(
			'img_style_section',
			[
				'label' => esc_html__( 'Image', 'pixi-adv-portfolio' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_control(
			'image_radius',
			[
				'label' => esc_html__( 'Border radius', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Title Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item h3' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'title_hover_color',
			[
				'label' => esc_html__( 'Title Hover Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item:hover h3' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .pixi-inner-item h3',
			]
		);

		$this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item p' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'selector' => '{{WRAPPER}} .pixi-inner-item p',
			]
		);
		$this->add_control(
			'text_hover_color',
			[
				'label' => esc_html__( 'Text Hover Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item:hover p' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();


		// content Style

		$this->start_controls_section(
			'content_style_section',
			[
				'label' => esc_html__( 'Content Item', 'pixi-adv-portfolio' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'item_border',
				'label' => __( 'Border', 'pixi-adv-portfolio' ),
				'selector' => '{{WRAPPER}}  .pixi-inner-item:hover .inner-content',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'item_box_shadow',
				'label' => __( 'Box Shadow', 'pixi-adv-portfolio' ),
				'selector' => '{{WRAPPER}} .pixi-inner-item:hover .inner-content',
			]
		);

		$this->add_control(
			'content_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item:hover .inner-content' => 'background: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'content_padding',
			[
				'label' => esc_html__( 'Padding', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item .inner-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'content_radius',
			[
				'label' => esc_html__( 'Border radius', 'pixi-adv-portfolio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .pixi-inner-item .inner-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

	}

	/**
	 * Render  widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();

		?>

		<div class="pixi-inner-item pixi-inner-col hover-style-1">
			<div class="inner-image">
				<img src="<?php echo esc_url($settings['widget_image']['url'],'pixi-adv-portfolio');?>" alt="<?php echo esc_attr($settings['widget_title'],'pixi-adv-portfolio');?>" class="img-fluid">
			</div>
			<div class="inner-content">
				<h3>
					<?php if ('media' == $settings['link_option'] ){  ?>
						<a class="port_popup img-fluid btn-icon" href="<?php echo esc_url($settings['widget_image']['url'],'pixi-adv-portfolio');?>">
					<?php  }
					
					if('custom' == $settings['link_option']){ ?>
						<a class="btn-icon" target="_blank" href="<?php echo esc_url($settings['widget_link']['url'],'pixi-adv-portfolio');?>">
					<?php  } ?>
					<?php echo esc_html($settings['widget_title'],'pixi-adv-portfolio');?></a>
				</h3>
				<p><?php echo esc_html($settings['widget_desc'],'pixi-adv-portfolio');?></p>
			</div>
		</div>
	


		<?php 

		

	}

}
